@@ -1,12 +1,25 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 import sys
 
 # These have been moved. They are retained here until all references to
 # them are moved at which point will mark as deprecated to ensure users
 # weren't using them directly.
 
-from ..common.object_names import callable_name
-from ..common.object_wrapper import (ObjectWrapper, wrap_object,
-        wrap_callable)
+from newrelic.common.object_names import callable_name
+from newrelic.common.object_wrapper import ObjectWrapper, wrap_object
 
 # From Python 3.X. In older Python versions it fails if attributes do
 # not exist and don't maintain a __wrapped__ attribute.
