@@ -18,26 +18,26 @@ interacting with the agent core.
 """
 
 from __future__ import print_function
-import os
-import sys
-import time
-import sched
-import logging
-import threading
+
 import atexit
+import logging
+import os
+import sched
+import sys
+import threading
+import time
 import traceback
+import warnings
 
 import newrelic
-import newrelic.core.config
 import newrelic.core.application
-
+import newrelic.core.config
 import newrelic.packages.six as six
-
 from newrelic.common.log_file import initialize_logging
-from newrelic.samplers.cpu_usage import cpu_usage_data_source
-from newrelic.samplers.memory_usage import memory_usage_data_source
-
 from newrelic.core.thread_utilization import thread_utilization_data_source
+from newrelic.samplers.cpu_usage import cpu_usage_data_source
+from newrelic.samplers.gc_data import garbage_collector_data_source
+from newrelic.samplers.memory_usage import memory_usage_data_source
 
 _logger = logging.getLogger(__name__)
 
@@ -46,36 +46,40 @@ def check_environment():
     # If running under uWSGI, then must be version 1.2.6 or newer. Must
     # also be run with '--enable-threads' option.
 
-    if 'uwsgi' in sys.modules:
+    if "uwsgi" in sys.modules:
         import uwsgi
 
-        if not hasattr(uwsgi, 'version_info'):
-            _logger.warning('The New Relic Python Agent requires version '
-                    '1.2.6 or newer of uWSGI. The newer '
-                    'version is required because older versions of uWSGI '
-                    'have a bug whereby it is not compliant with the WSGI '
-                    '(PEP 333) specification. This bug in uWSGI will result '
-                    'in data being reported incorrectly. For more details see '
-                    'https://newrelic.com/docs/python/python-agent-and-uwsgi.')
-        elif ((hasattr(uwsgi, 'version_info') and
-                  uwsgi.version_info[:3] < (1, 2, 6))):
-            _logger.warning('The New Relic Python Agent requires version '
-                    '1.2.6 or newer of uWSGI, you are using %r. The newer '
-                    'version is required because older versions of uWSGI '
-                    'have a bug whereby it is not compliant with the WSGI '
-                    '(PEP 333) specification. This bug in uWSGI will result '
-                    'in data being reported incorrectly. For more details see '
-                    'https://newrelic.com/docs/python/python-agent-and-uwsgi.',
-                    '.'.join(map(str, uwsgi.version_info[:3])))
+        if not hasattr(uwsgi, "version_info"):
+            _logger.warning(
+                "The New Relic Python Agent requires version "
+                "1.2.6 or newer of uWSGI. The newer "
+                "version is required because older versions of uWSGI "
+                "have a bug whereby it is not compliant with the WSGI "
+                "(PEP 333) specification. This bug in uWSGI will result "
+                "in data being reported incorrectly. For more details see "
+                "https://newrelic.com/docs/python/python-agent-and-uwsgi."
+            )
+        elif hasattr(uwsgi, "version_info") and uwsgi.version_info[:3] < (1, 2, 6):
+            _logger.warning(
+                "The New Relic Python Agent requires version "
+                "1.2.6 or newer of uWSGI, you are using %r. The newer "
+                "version is required because older versions of uWSGI "
+                "have a bug whereby it is not compliant with the WSGI "
+                "(PEP 333) specification. This bug in uWSGI will result "
+                "in data being reported incorrectly. For more details see "
+                "https://newrelic.com/docs/python/python-agent-and-uwsgi.",
+                ".".join(map(str, uwsgi.version_info[:3])),
+            )
 
-        if (hasattr(uwsgi, 'opt') and hasattr(uwsgi.opt, 'get') and
-                not uwsgi.opt.get('enable-threads')):
-            _logger.warning('The New Relic Python Agent requires that when '
-                    'using uWSGI that the enable-threads option be given '
-                    'to uwsgi when it is run. If the option is not supplied '
-                    'then threading will not be enabled and you will see no '
-                    'data being reported by the agent. For more details see '
-                    'https://newrelic.com/docs/python/python-agent-and-uwsgi.')
+        if hasattr(uwsgi, "opt") and hasattr(uwsgi.opt, "get") and not uwsgi.opt.get("enable-threads"):
+            _logger.warning(
+                "The New Relic Python Agent requires that when "
+                "using uWSGI that the enable-threads option be given "
+                "to uwsgi when it is run. If the option is not supplied "
+                "then threading will not be enabled and you will see no "
+                "data being reported by the agent. For more details see "
+                "https://newrelic.com/docs/python/python-agent-and-uwsgi."
+            )
 
 
 class Agent(object):
@@ -124,11 +128,11 @@ class Agent(object):
     _registration_callables = {}
 
     @staticmethod
-    def run_on_startup(callable):
+    def run_on_startup(callable):  # pylint: disable=W0622
         Agent._startup_callables.append(callable)
 
     @staticmethod
-    def run_on_registration(application, callable):
+    def run_on_registration(application, callable):  # pylint: disable=W0622
         callables = Agent._registration_callables.setdefault(application, [])
         callables.append(callable)
 
@@ -151,39 +155,38 @@ class Agent(object):
 
         initialize_logging(settings.log_file, settings.log_level)
 
-        _logger.info('New Relic Python Agent (%s)' % newrelic.version)
+        _logger.info("New Relic Python Agent (%s)" % newrelic.version)
 
         check_environment()
 
-        if 'NEW_RELIC_ADMIN_COMMAND' in os.environ:
+        if "NEW_RELIC_ADMIN_COMMAND" in os.environ:
             if settings.debug.log_agent_initialization:
-                _logger.info('Monitored application started using the '
-                        'newrelic-admin command with command line of %s.',
-                        os.environ['NEW_RELIC_ADMIN_COMMAND'])
+                _logger.info(
+                    "Monitored application started using the newrelic-admin command with command line of %s.",
+                    os.environ["NEW_RELIC_ADMIN_COMMAND"],
+                )
             else:
-                _logger.debug('Monitored application started using the '
-                        'newrelic-admin command with command line of %s.',
-                        os.environ['NEW_RELIC_ADMIN_COMMAND'])
+                _logger.debug(
+                    "Monitored application started using the newrelic-admin command with command line of %s.",
+                    os.environ["NEW_RELIC_ADMIN_COMMAND"],
+                )
 
         with Agent._instance_lock:
             if not Agent._instance:
                 if settings.debug.log_agent_initialization:
-                    _logger.info('Creating instance of Python agent in '
-                            'process %d.', os.getpid())
-                    _logger.info('Agent was initialized from: %r',
-                            ''.join(traceback.format_stack()[:-1]))
+                    _logger.info("Creating instance of Python agent in process %d.", os.getpid())
+                    _logger.info("Agent was initialized from: %r", "".join(traceback.format_stack()[:-1]))
                 else:
-                    _logger.debug('Creating instance of Python agent in '
-                            'process %d.', os.getpid())
-                    _logger.debug('Agent was initialized from: %r',
-                            ''.join(traceback.format_stack()[:-1]))
+                    _logger.debug("Creating instance of Python agent in process %d.", os.getpid())
+                    _logger.debug("Agent was initialized from: %r", "".join(traceback.format_stack()[:-1]))
 
                 instance = Agent(settings)
-                _logger.debug('Registering builtin data sources.')
+                _logger.debug("Registering builtin data sources.")
 
                 instance.register_data_source(cpu_usage_data_source)
                 instance.register_data_source(memory_usage_data_source)
                 instance.register_data_source(thread_utilization_data_source)
+                instance.register_data_source(garbage_collector_data_source)
 
                 Agent._instance = instance
 
@@ -196,7 +199,7 @@ class Agent(object):
 
         """
 
-        _logger.debug('Initializing Python agent.')
+        _logger.debug("Initializing Python agent.")
 
         self._creation_time = time.time()
         self._process_id = os.getpid()
@@ -204,9 +207,8 @@ class Agent(object):
         self._applications = {}
         self._config = config
 
-        self._harvest_thread = threading.Thread(target=self._harvest_loop,
-                name='NR-Harvest-Thread')
-        self._harvest_thread.setDaemon(True)
+        self._harvest_thread = threading.Thread(target=self._harvest_loop, name="NR-Harvest-Thread")
+        self._harvest_thread.daemon = True
         self._harvest_shutdown = threading.Event()
 
         self._default_harvest_count = 0
@@ -215,9 +217,7 @@ class Agent(object):
         self._last_flexible_harvest = 0.0
         self._default_harvest_duration = 0.0
         self._flexible_harvest_duration = 0.0
-        self._scheduler = sched.scheduler(
-                self._harvest_timer,
-                self._harvest_shutdown.wait)
+        self._scheduler = sched.scheduler(self._harvest_timer, self._harvest_shutdown.wait)
 
         self._process_shutdown = False
 
@@ -236,9 +236,10 @@ class Agent(object):
             # append our atexit hook to any pre-existing ones to prevent
             # overwriting them.
 
-            if 'uwsgi' in sys.modules:
+            if "uwsgi" in sys.modules:
                 import uwsgi
-                uwsgi_original_atexit_callback = getattr(uwsgi, 'atexit', None)
+
+                uwsgi_original_atexit_callback = getattr(uwsgi, "atexit", None)
 
                 def uwsgi_atexit_callback():
                     self._atexit_shutdown()
@@ -252,28 +253,16 @@ class Agent(object):
     def dump(self, file):
         """Dumps details about the agent to the file object."""
 
-        print('Time Created: %s' % (
-                time.asctime(time.localtime(self._creation_time))), file=file)
-        print('Initialization PID: %s' % (
-                self._process_id), file=file)
-        print('Default Harvest Count: %d' % (
-                self._default_harvest_count), file=file)
-        print('Flexible Harvest Count: %d' % (
-                self._flexible_harvest_count), file=file)
-        print('Last Default Harvest: %s' % (
-                time.asctime(time.localtime(self._last_default_harvest))),
-                file=file)
-        print('Last Flexible Harvest: %s' % (
-                time.asctime(time.localtime(self._last_flexible_harvest))),
-                file=file)
-        print('Default Harvest Duration: %.2f' % (
-                self._default_harvest_duration), file=file)
-        print('Flexible Harvest Duration: %.2f' % (
-                self._flexible_harvest_duration), file=file)
-        print('Agent Shutdown: %s' % (
-                self._harvest_shutdown.isSet()), file=file)
-        print('Applications: %r' % (
-                sorted(self._applications.keys())), file=file)
+        print("Time Created: %s" % (time.asctime(time.localtime(self._creation_time))), file=file)
+        print("Initialization PID: %s" % (self._process_id), file=file)
+        print("Default Harvest Count: %d" % (self._default_harvest_count), file=file)
+        print("Flexible Harvest Count: %d" % (self._flexible_harvest_count), file=file)
+        print("Last Default Harvest: %s" % (time.asctime(time.localtime(self._last_default_harvest))), file=file)
+        print("Last Flexible Harvest: %s" % (time.asctime(time.localtime(self._last_flexible_harvest))), file=file)
+        print("Default Harvest Duration: %.2f" % (self._default_harvest_duration), file=file)
+        print("Flexible Harvest Duration: %.2f" % (self._flexible_harvest_duration), file=file)
+        print("Agent Shutdown: %s" % (self._harvest_shutdown.isSet()), file=file)
+        print("Applications: %r" % (sorted(self._applications.keys())), file=file)
 
     def global_settings(self):
         """Returns the global default settings object. If access is
@@ -306,8 +295,7 @@ class Agent(object):
         if application:
             return application.attribute_filter
 
-    def activate_application(self, app_name, linked_applications=[],
-                             timeout=None, uninstrumented_modules=None):
+    def activate_application(self, app_name, linked_applications=None, timeout=None, uninstrumented_modules=None):
         """Initiates activation for the named application if this has
         not been done previously. If an attempt to trigger the
         activation of the application has already been performed,
@@ -326,6 +314,7 @@ class Agent(object):
         handshake to get back configuration settings for application.
 
         """
+        linked_applications = linked_applications if linked_applications is not None else []
 
         if not self._config.enabled:
             return
@@ -355,51 +344,43 @@ class Agent(object):
 
                 if process_id != self._process_id:
                     _logger.warning(
-                            'Attempt to activate application in a process '
-                            'different to where the agent harvest thread was '
-                            'started. No data will be reported for this '
-                            'process with pid of %d. Creation of the harvest '
-                            'thread this application occurred in process with '
-                            'pid %d. If no data at all is being reported for '
-                            'your application, see '
-                            'https://docs.newrelic.com/docs/agents/'
-                            'python-agent/troubleshooting/'
-                            'activate-application-warning-python '
-                            'for troubleshooting steps. If the issue '
-                            'persists, please send debug logs to New Relic '
-                            'support for assistance.',
-                            process_id,
-                            self._process_id)
+                        "Attempt to activate application in a process "
+                        "different to where the agent harvest thread was "
+                        "started. No data will be reported for this "
+                        "process with pid of %d. Creation of the harvest "
+                        "thread this application occurred in process with "
+                        "pid %d. If no data at all is being reported for "
+                        "your application, see "
+                        "https://docs.newrelic.com/docs/agents/"
+                        "python-agent/troubleshooting/"
+                        "activate-application-warning-python "
+                        "for troubleshooting steps. If the issue "
+                        "persists, please send debug logs to New Relic "
+                        "support for assistance.",
+                        process_id,
+                        self._process_id,
+                    )
 
                 if settings.debug.log_agent_initialization:
-                    _logger.info('Creating application instance for %r '
-                            'in process %d.', app_name, os.getpid())
-                    _logger.info('Application was activated from: %r',
-                            ''.join(traceback.format_stack()[:-1]))
+                    _logger.info("Creating application instance for %r in process %d.", app_name, os.getpid())
+                    _logger.info("Application was activated from: %r", "".join(traceback.format_stack()[:-1]))
                 else:
-                    _logger.debug('Creating application instance for %r '
-                            'in process %d.', app_name, os.getpid())
-                    _logger.debug('Application was activated from: %r',
-                            ''.join(traceback.format_stack()[:-1]))
+                    _logger.debug("Creating application instance for %r in process %d.", app_name, os.getpid())
+                    _logger.debug("Application was activated from: %r", "".join(traceback.format_stack()[:-1]))
 
                 linked_applications = sorted(set(linked_applications))
-                application = newrelic.core.application.Application(
-                        app_name, linked_applications)
+                application = newrelic.core.application.Application(app_name, linked_applications)
                 application._uninstrumented = uninstrumented_modules
                 self._applications[app_name] = application
                 activate_session = True
 
                 # Register any data sources with the application.
 
-                for source, name, settings, properties in \
-                        self._data_sources.get(None, []):
-                    application.register_data_source(source, name,
-                            settings, **properties)
+                for source, name, settings, properties in self._data_sources.get(None, []):
+                    application.register_data_source(source, name, settings, **properties)
 
-                for source, name, settings, properties in \
-                        self._data_sources.get(app_name, []):
-                    application.register_data_source(source, name,
-                            settings, **properties)
+                for source, name, settings, properties in self._data_sources.get(app_name, []):
+                    application.register_data_source(source, name, settings, **properties)
 
             else:
                 # Do some checks to see whether try to reactivate the
@@ -443,27 +424,21 @@ class Agent(object):
 
         return self._applications.get(app_name, None)
 
-    def register_data_source(self, source, application=None,
-                name=None, settings=None, **properties):
-        """Registers the specified data source.
+    def register_data_source(self, source, application=None, name=None, settings=None, **properties):
+        """Registers the specified data source."""
 
-        """
-
-        _logger.debug('Register data source with agent %r.',
-                (source, application, name, settings, properties))
+        _logger.debug("Register data source with agent %r.", (source, application, name, settings, properties))
 
         with self._lock:
             # Remember the data sources in case we need them later.
 
-            self._data_sources.setdefault(application, []).append(
-                    (source, name, settings, properties))
+            self._data_sources.setdefault(application, []).append((source, name, settings, properties))
 
             if application is None:
                 # Bind to any applications that already exist.
 
                 for application in list(six.itervalues(self._applications)):
-                    application.register_data_source(source, name,
-                            settings, **properties)
+                    application.register_data_source(source, name, settings, **properties)
 
             else:
                 # Bind to specific application if it exists.
@@ -471,16 +446,14 @@ class Agent(object):
                 instance = self._applications.get(application)
 
                 if instance is not None:
-                    instance.register_data_source(source, name,
-                            settings, **properties)
+                    instance.register_data_source(source, name, settings, **properties)
 
     def remove_thread_utilization(self):
 
-        _logger.debug('Removing thread utilization data source from all '
-                'applications')
+        _logger.debug("Removing thread utilization data source from all applications")
 
         source_name = thread_utilization_data_source.__name__
-        factory_name = 'Thread Utilization'
+        factory_name = "Thread Utilization"
 
         with self._lock:
             source_names = [s[0].__name__ for s in self._data_sources[None]]
@@ -499,16 +472,30 @@ class Agent(object):
         # thread.concurrency attributes
 
         from newrelic.core.thread_utilization import _utilization_trackers
+
         _utilization_trackers.clear()
 
-    def record_exception(self, app_name, exc=None, value=None, tb=None,
-            params={}, ignore_errors=[]):
+    def record_exception(self, app_name, exc=None, value=None, tb=None, params=None, ignore_errors=None):
+        # Deprecation Warning
+        warnings.warn(
+            ("The record_exception function is deprecated. Please use the new api named notice_error instead."),
+            DeprecationWarning,
+        )
 
+        self.notice_error(app_name, error=(exc, value, tb), attributes=params, ignore=ignore_errors)
+
+    def notice_error(self, app_name, error=None, attributes=None, expected=None, ignore=None, status_code=None):
         application = self._applications.get(app_name, None)
         if application is None or not application.active:
             return
 
-        application.record_exception(exc, value, tb, params, ignore_errors)
+        application.notice_error(
+            error=error,
+            attributes=attributes,
+            expected=expected,
+            ignore=ignore,
+            status_code=status_code,
+        )
 
     def record_custom_metric(self, app_name, name, value):
         """Records a basic metric for the named application. If there has
@@ -562,7 +549,7 @@ class Agent(object):
             application.harvest(flexible=True)
             application.harvest(flexible=False)
 
-    def normalize_name(self, app_name, name, rule_type='url'):
+    def normalize_name(self, app_name, name, rule_type="url"):
         application = self._applications.get(app_name, None)
         if application is None:
             return name, False
@@ -573,20 +560,22 @@ class Agent(object):
         application = self._applications.get(app_name, None)
         return application.compute_sampled()
 
+    def _harvest_shutdown_is_set(self):
+        try:
+            return self._harvest_shutdown.is_set()
+        except TypeError:
+            return self._harvest_shutdown.isSet()
+
     def _harvest_flexible(self, shutdown=False):
-        if not self._harvest_shutdown.isSet():
+        if not self._harvest_shutdown_is_set():
             event_harvest_config = self.global_settings().event_harvest_config
 
-            self._scheduler.enter(
-                    event_harvest_config.report_period_ms / 1000.0,
-                    1,
-                    self._harvest_flexible,
-                    ())
-            _logger.debug('Commencing harvest[flexible] of application data.')
+            self._scheduler.enter(event_harvest_config.report_period_ms / 1000.0, 1, self._harvest_flexible, ())
+            _logger.debug("Commencing harvest[flexible] of application data.")
         elif not shutdown:
             return
         else:
-            _logger.debug('Commencing final harvest[flexible] of application data.')
+            _logger.debug("Commencing final harvest[flexible] of application data.")
 
         self._flexible_harvest_count += 1
         self._last_flexible_harvest = time.time()
@@ -595,23 +584,22 @@ class Agent(object):
             try:
                 application.harvest(shutdown=False, flexible=True)
             except Exception:
-                _logger.exception('Failed to harvest data '
-                                  'for %s.' % application.name)
+                _logger.exception("Failed to harvest data for %s." % application.name)
 
-        self._flexible_harvest_duration = \
-                time.time() - self._last_flexible_harvest
+        self._flexible_harvest_duration = time.time() - self._last_flexible_harvest
 
-        _logger.debug('Completed harvest[flexible] of application data in %.2f '
-                'seconds.', self._flexible_harvest_duration)
+        _logger.debug(
+            "Completed harvest[flexible] of application data in %.2f seconds.", self._flexible_harvest_duration
+        )
 
     def _harvest_default(self, shutdown=False):
-        if not self._harvest_shutdown.isSet():
+        if not self._harvest_shutdown_is_set():
             self._scheduler.enter(60.0, 2, self._harvest_default, ())
-            _logger.debug('Commencing harvest[default] of application data.')
+            _logger.debug("Commencing harvest[default] of application data.")
         elif not shutdown:
             return
         else:
-            _logger.debug('Commencing final harvest[default] of application data.')
+            _logger.debug("Commencing final harvest[default] of application data.")
 
         self._default_harvest_count += 1
         self._last_default_harvest = time.time()
@@ -620,36 +608,25 @@ class Agent(object):
             try:
                 application.harvest(shutdown, flexible=False)
             except Exception:
-                _logger.exception('Failed to harvest data '
-                                  'for %s.' % application.name)
+                _logger.exception("Failed to harvest data for %s." % application.name)
 
-        self._default_harvest_duration = \
-                time.time() - self._last_default_harvest
+        self._default_harvest_duration = time.time() - self._last_default_harvest
 
-        _logger.debug('Completed harvest[default] of application data in %.2f '
-                'seconds.', self._default_harvest_duration)
+        _logger.debug("Completed harvest[default] of application data in %.2f seconds.", self._default_harvest_duration)
 
     def _harvest_timer(self):
-        if self._harvest_shutdown.isSet():
+        if self._harvest_shutdown_is_set():
             return float("inf")
         return time.time()
 
     def _harvest_loop(self):
-        _logger.debug('Entering harvest loop.')
+        _logger.debug("Entering harvest loop.")
 
         settings = newrelic.core.config.global_settings()
         event_harvest_config = settings.event_harvest_config
 
-        self._scheduler.enter(
-                event_harvest_config.report_period_ms / 1000.0,
-                1,
-                self._harvest_flexible,
-                ())
-        self._scheduler.enter(
-                60.0,
-                2,
-                self._harvest_default,
-                ())
+        self._scheduler.enter(event_harvest_config.report_period_ms / 1000.0, 1, self._harvest_flexible, ())
+        self._scheduler.enter(60.0, 2, self._harvest_default, ())
 
         try:
             self._scheduler.run()
@@ -660,33 +637,36 @@ class Agent(object):
             # background harvest thread is still running.
 
             if self._process_shutdown:
-                _logger.exception('Unexpected exception in main harvest '
-                        'loop when process being shutdown. This can occur '
-                        'in rare cases due to the main thread cleaning up '
-                        'and destroying objects while the background harvest '
-                        'thread is still running. If this message occurs '
-                        'rarely, it can be ignored. If the message occurs '
-                        'on a regular basis, then please report it to New '
-                        'Relic support for further investigation.')
+                _logger.exception(
+                    "Unexpected exception in main harvest "
+                    "loop when process being shutdown. This can occur "
+                    "in rare cases due to the main thread cleaning up "
+                    "and destroying objects while the background harvest "
+                    "thread is still running. If this message occurs "
+                    "rarely, it can be ignored. If the message occurs "
+                    "on a regular basis, then please report it to New "
+                    "Relic support for further investigation."
+                )
 
             else:
-                _logger.exception('Unexpected exception in main harvest '
-                        'loop. Please report this problem to New Relic '
-                        'support for further investigation.')
+                _logger.exception(
+                    "Unexpected exception in main harvest "
+                    "loop. Please report this problem to New Relic "
+                    "support for further investigation."
+                )
 
     def activate_agent(self):
         """Starts the main background for the agent."""
         with Agent._instance_lock:
             # Skip this if agent is not actually enabled.
             if not self._config.enabled:
-                _logger.warning('The Python Agent is not enabled.')
+                _logger.warning("The Python Agent is not enabled.")
                 return
             elif self._config.serverless_mode.enabled:
-                _logger.debug(
-                        'Harvest thread is disabled due to serverless mode.')
+                _logger.debug("Harvest thread is disabled due to serverless mode.")
                 return
             elif self._config.debug.disable_harvest_until_shutdown:
-                _logger.debug('Harvest thread is disabled.')
+                _logger.debug("Harvest thread is disabled.")
                 return
 
             # Skip this if background thread already running.
@@ -694,12 +674,12 @@ class Agent(object):
             if self._harvest_thread.is_alive():
                 return
 
-            _logger.debug('Activating agent instance.')
+            _logger.debug("Activating agent instance.")
 
             for callable in self._startup_callables:
                 callable()
 
-            _logger.debug('Start Python Agent main thread.')
+            _logger.debug("Start Python Agent main thread.")
 
             self._harvest_thread.start()
 
@@ -715,32 +695,24 @@ class Agent(object):
         self.shutdown_agent()
 
     def shutdown_agent(self, timeout=None):
-        if self._harvest_shutdown.isSet():
+        if self._harvest_shutdown_is_set():
             return
 
         if timeout is None:
             timeout = self._config.shutdown_timeout
 
-        _logger.info('New Relic Python Agent Shutdown')
+        _logger.info("New Relic Python Agent Shutdown")
 
         # Schedule final harvests. This is OK to schedule across threads since
         # the entries will only be added to the end of the list and won't be
         # popped until harvest_shutdown is set.
-        self._scheduler.enter(
-                float('inf'),
-                3,
-                self._harvest_flexible,
-                (True,))
-        self._scheduler.enter(
-                float('inf'),
-                4,
-                self._harvest_default,
-                (True,))
+        self._scheduler.enter(float("inf"), 3, self._harvest_flexible, (True,))
+        self._scheduler.enter(float("inf"), 4, self._harvest_default, (True,))
 
         self._harvest_shutdown.set()
 
         if self._config.debug.disable_harvest_until_shutdown:
-            _logger.debug('Start Python Agent main thread on shutdown.')
+            _logger.debug("Start Python Agent main thread on shutdown.")
             self._harvest_thread.start()
 
         if self._harvest_thread.is_alive():
@@ -766,12 +738,9 @@ def shutdown_agent(timeout=None):
     agent.shutdown_agent(timeout)
 
 
-def register_data_source(source, application=None, name=None,
-        settings=None, **properties):
+def register_data_source(source, application=None, name=None, settings=None, **properties):
     agent = agent_instance()
-    agent.register_data_source(source,
-            application and application.name or None, name, settings,
-            **properties)
+    agent.register_data_source(source, application and application.name or None, name, settings, **properties)
 
 
 def _remove_thread_utilization():
