@@ -1,3 +1,17 @@
+# Copyright 2010 New Relic, Inc.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#      http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 try:
     import urlparse
 except ImportError:
@@ -5,8 +19,9 @@ except ImportError:
 
 import newrelic.packages.six as six
 
-from newrelic.agent import (current_transaction,
-    wrap_function_wrapper, ExternalTrace)
+from newrelic.api.external_trace import ExternalTrace
+from newrelic.api.transaction import current_transaction
+from newrelic.common.object_wrapper import wrap_function_wrapper
 
 def _nr_wrapper_opener_director_open_(wrapped, instance, args, kwargs):
     transaction = current_transaction()
@@ -27,7 +42,7 @@ def _nr_wrapper_opener_director_open_(wrapped, instance, args, kwargs):
     if details.hostname is None:
         return wrapped(*args, **kwargs)
 
-    with ExternalTrace(transaction, 'urllib2', url):
+    with ExternalTrace('urllib2', url):
         return wrapped(*args, **kwargs)
 
 def instrument(module):
