@@ -13,28 +13,33 @@
 # limitations under the License.
 
 import pytest
-
-from testing_support.fixtures import (code_coverage_fixture,
-        collector_agent_registration_fixture, collector_available_fixture)
+from testing_support.fixtures import (  # noqa: F401; pylint: disable=W0611
+    code_coverage_fixture,
+    collector_agent_registration_fixture,
+    collector_available_fixture,
+)
+from testing_support.fixtures import (  # noqa: F401; pylint: disable=W0611
+    newrelic_caplog as caplog,
+)
 
 _coverage_source = [
-    'newrelic.hooks.framework_fastapi',
+    "newrelic.hooks.framework_fastapi",
 ]
 
 code_coverage = code_coverage_fixture(source=_coverage_source)
 
 _default_settings = {
-    'transaction_tracer.explain_threshold': 0.0,
-    'transaction_tracer.transaction_threshold': 0.0,
-    'transaction_tracer.stack_trace_threshold': 0.0,
-    'debug.log_data_collector_payloads': True,
-    'debug.record_transaction_failure': True,
-    'debug.log_autorum_middleware': True,
+    "transaction_tracer.explain_threshold": 0.0,
+    "transaction_tracer.transaction_threshold": 0.0,
+    "transaction_tracer.stack_trace_threshold": 0.0,
+    "debug.log_data_collector_payloads": True,
+    "debug.record_transaction_failure": True,
+    "debug.log_autorum_middleware": True,
 }
 
 collector_agent_registration = collector_agent_registration_fixture(
-        app_name='Python Agent Test (framework_fastapi)',
-        default_settings=_default_settings)
+    app_name="Python Agent Test (framework_fastapi)", default_settings=_default_settings
+)
 
 
 @pytest.fixture(scope="session")
