@@ -12,19 +12,28 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import logging
+
 import pytest
 from testing_support.fixtures import validate_transaction_metrics
 
 
-@pytest.mark.parametrize("endpoint,transaction_name", (
-    ("/sync", "_target_application:sync"),
-    ("/async", "_target_application:non_sync"),
-))
-def test_application(app, endpoint, transaction_name):
-    @validate_transaction_metrics(transaction_name,
-        scoped_metrics=[("Function/" + transaction_name, 1)])
+@pytest.mark.parametrize(
+    "endpoint,transaction_name",
+    (
+        ("/sync", "_target_application:sync"),
+        ("/async", "_target_application:non_sync"),
+    ),
+)
+def test_application(caplog, app, endpoint, transaction_name):
+    caplog.set_level(logging.ERROR)
+
+    @validate_transaction_metrics(transaction_name, scoped_metrics=[("Function/" + transaction_name, 1)])
     def _test():
         response = app.get(endpoint)
         assert response.status == 200
 
+        # Catch context propagation error messages
+        assert not caplog.records
+
     _test()
