@@ -12,23 +12,24 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import pytest
-
-from testing_support.fixtures import (validate_transaction_metrics,
-    validate_transaction_errors, override_application_settings)
-
-from conftest import async_handler_support, skip_if_not_async_handler_support
-
+from conftest import (  # pylint: disable=E0611
+    async_handler_support,
+    skip_if_not_async_handler_support,
+)
+from testing_support.fixtures import (
+    validate_transaction_errors,
+    validate_transaction_metrics,
+)
 
 scoped_metrics = [
-        ('Function/flask.app:Flask.wsgi_app', 1),
-        ('Python/WSGI/Application', 1),
-        ('Python/WSGI/Response', 1),
-        ('Python/WSGI/Finalize', 1),
-        ('Function/flask.app:Flask.preprocess_request', 1),
-        ('Function/flask.app:Flask.process_response', 1),
-        ('Function/flask.app:Flask.do_teardown_request', 1),
-        ('Function/werkzeug.wsgi:ClosingIterator.close', 1),
+    ("Function/flask.app:Flask.wsgi_app", 1),
+    ("Python/WSGI/Application", 1),
+    ("Python/WSGI/Response", 1),
+    ("Python/WSGI/Finalize", 1),
+    ("Function/flask.app:Flask.preprocess_request", 1),
+    ("Function/flask.app:Flask.process_response", 1),
+    ("Function/flask.app:Flask.do_teardown_request", 1),
+    ("Function/werkzeug.wsgi:ClosingIterator.close", 1),
 ]
 
 
@@ -48,46 +49,44 @@ def target_application():
         from _test_views_async import _test_application
     return _test_application
 
+
 @validate_transaction_errors(errors=[])
-@validate_transaction_metrics('_test_views:test_view',
-        scoped_metrics=scoped_metrics)
+@validate_transaction_metrics("_test_views:test_view", scoped_metrics=scoped_metrics)
 def test_class_based_view():
     application = target_application()
-    response = application.get('/view')
-    response.mustcontain('VIEW RESPONSE')
+    response = application.get("/view")
+    response.mustcontain("VIEW RESPONSE")
+
 
-@pytest.mark.xfail(reason="Currently broken in flask.")
 @skip_if_not_async_handler_support
 @validate_transaction_errors(errors=[])
-@validate_transaction_metrics('_test_views_async:test_async_view',
-        scoped_metrics=scoped_metrics)
+@validate_transaction_metrics("_test_views_async:test_async_view", scoped_metrics=scoped_metrics)
 def test_class_based_async_view():
     application = target_application()
-    response = application.get('/async_view')
-    response.mustcontain('ASYNC VIEW RESPONSE')
+    response = application.get("/async_view")
+    response.mustcontain("ASYNC VIEW RESPONSE")
+
 
 @validate_transaction_errors(errors=[])
-@validate_transaction_metrics('_test_views:test_methodview',
-        scoped_metrics=scoped_metrics)
+@validate_transaction_metrics("_test_views:test_methodview", scoped_metrics=scoped_metrics)
 def test_get_method_view():
     application = target_application()
-    response = application.get('/methodview')
-    response.mustcontain('METHODVIEW GET RESPONSE')
+    response = application.get("/methodview")
+    response.mustcontain("METHODVIEW GET RESPONSE")
+
 
 @validate_transaction_errors(errors=[])
-@validate_transaction_metrics('_test_views:test_methodview',
-        scoped_metrics=scoped_metrics)
+@validate_transaction_metrics("_test_views:test_methodview", scoped_metrics=scoped_metrics)
 def test_post_method_view():
     application = target_application()
-    response = application.post('/methodview')
-    response.mustcontain('METHODVIEW POST RESPONSE')
+    response = application.post("/methodview")
+    response.mustcontain("METHODVIEW POST RESPONSE")
+
 
-@pytest.mark.xfail(reason="Currently broken in flask.")
 @skip_if_not_async_handler_support
 @validate_transaction_errors(errors=[])
-@validate_transaction_metrics('_test_views_async:test_async_methodview',
-        scoped_metrics=scoped_metrics)
+@validate_transaction_metrics("_test_views_async:test_async_methodview", scoped_metrics=scoped_metrics)
 def test_get_method_async_view():
     application = target_application()
-    response = application.get('/async_methodview')
-    response.mustcontain('ASYNC METHODVIEW GET RESPONSE')
+    response = application.get("/async_methodview")
+    response.mustcontain("ASYNC METHODVIEW GET RESPONSE")
